@@ -292,7 +292,7 @@ class CreateKeyRequest(AbstractModel):
         :type Alias: str
         :param Description: CMK 的描述，最大1024字节
         :type Description: str
-        :param KeyUsage: 指定key的用途，默认为  "ENCRYPT_DECRYPT" 表示创建对称加解密密钥，其它支持用途 “ASYMMETRIC_DECRYPT_RSA_2048” 表示创建用于加解密的RSA2048非对称密钥，“ASYMMETRIC_DECRYPT_SM2” 表示创建用于加解密的SM2非对称密钥
+        :param KeyUsage: 指定key的用途，默认为  "ENCRYPT_DECRYPT" 表示创建对称加解密密钥，其它支持用途 “ASYMMETRIC_DECRYPT_RSA_2048” 表示创建用于加解密的RSA2048非对称密钥，“ASYMMETRIC_DECRYPT_SM2” 表示创建用于加解密的SM2非对称密钥, “ASYMMETRIC_SIGN_VERIFY_SM2” 表示创建用于签名验签的SM2非对称密钥,
         :type KeyUsage: str
         :param Type: 指定key类型，默认为1，1表示默认类型，由KMS创建CMK密钥，2 表示EXTERNAL 类型，该类型需要用户导入密钥材料，参考 GetParametersForImport 和 ImportKeyMaterial 接口
         :type Type: int
@@ -1715,7 +1715,7 @@ class KeyMetadata(AbstractModel):
         :type Description: str
         :param KeyState: CMK的状态， 取值为：Enabled | Disabled | PendingDelete | PendingImport | Archived
         :type KeyState: str
-        :param KeyUsage: CMK用途，取值为: ENCRYPT_DECRYPT | ASYMMETRIC_DECRYPT_RSA_2048 | ASYMMETRIC_DECRYPT_SM2
+        :param KeyUsage: CMK用途，取值为: ENCRYPT_DECRYPT | ASYMMETRIC_DECRYPT_RSA_2048 | ASYMMETRIC_DECRYPT_SM2 | ASYMMETRIC_SIGN_VERIFY_SM2
         :type KeyUsage: str
         :param Type: CMK类型，2 表示符合FIPS标准，4表示符合国密标准
         :type Type: int
@@ -1791,11 +1791,14 @@ class ListAlgorithmsResponse(AbstractModel):
         :type SymmetricAlgorithms: list of AlgorithmInfo
         :param AsymmetricAlgorithms: 本地区支持的非对称加密算法
         :type AsymmetricAlgorithms: list of AlgorithmInfo
+        :param AsymmetricSignVerifyAlgorithms: 本地区支持的非对称签名验签算法
+        :type AsymmetricSignVerifyAlgorithms: list of AlgorithmInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.SymmetricAlgorithms = None
         self.AsymmetricAlgorithms = None
+        self.AsymmetricSignVerifyAlgorithms = None
         self.RequestId = None
 
 
@@ -1812,6 +1815,12 @@ class ListAlgorithmsResponse(AbstractModel):
                 obj = AlgorithmInfo()
                 obj._deserialize(item)
                 self.AsymmetricAlgorithms.append(obj)
+        if params.get("AsymmetricSignVerifyAlgorithms") is not None:
+            self.AsymmetricSignVerifyAlgorithms = []
+            for item in params.get("AsymmetricSignVerifyAlgorithms"):
+                obj = AlgorithmInfo()
+                obj._deserialize(item)
+                self.AsymmetricSignVerifyAlgorithms.append(obj)
         self.RequestId = params.get("RequestId")
 
 
@@ -1836,7 +1845,7 @@ class ListKeyDetailRequest(AbstractModel):
         :type SearchKeyAlias: str
         :param Origin: 根据CMK类型筛选， "TENCENT_KMS" 表示筛选密钥材料由KMS创建的CMK， "EXTERNAL" 表示筛选密钥材料需要用户导入的 EXTERNAL类型CMK，"ALL" 或者不设置表示两种类型都查询，大小写敏感。
         :type Origin: str
-        :param KeyUsage: 根据CMK的KeyUsage筛选，ALL表示筛选全部，可使用的参数为：ALL 或 ENCRYPT_DECRYPT 或 ASYMMETRIC_DECRYPT_RSA_2048 或 ASYMMETRIC_DECRYPT_SM2，为空则默认筛选ENCRYPT_DECRYPT类型
+        :param KeyUsage: 根据CMK的KeyUsage筛选，ALL表示筛选全部，可使用的参数为：ALL 或 ENCRYPT_DECRYPT 或 ASYMMETRIC_DECRYPT_RSA_2048 或 ASYMMETRIC_DECRYPT_SM2 或 ASYMMETRIC_SIGN_VERIFY_SM2，为空则默认筛选ENCRYPT_DECRYPT类型
         :type KeyUsage: str
         :param TagFilters: 标签过滤条件
         :type TagFilters: list of TagFilter
@@ -2107,6 +2116,56 @@ class ScheduleKeyDeletionResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class SignByAsymmetricKeyRequest(AbstractModel):
+    """SignByAsymmetricKey请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Algorithm: 签名算法，支持的算法：SM2DSA
+        :type Algorithm: str
+        :param Message: 消息原文或消息摘要。如果提供的是消息原文，则消息原文的长度（Base64编码前的长度）不超过4096字节。如果提供的是消息摘要，SM2签名算法的消息摘要长度（Base64编码前的长度）必须等于32字节
+        :type Message: str
+        :param KeyId: 密钥的唯一标识
+        :type KeyId: str
+        :param MessageType: 消息类型：RAW，DIGEST，如果不传，默认为RAW，表示消息原文。
+        :type MessageType: str
+        """
+        self.Algorithm = None
+        self.Message = None
+        self.KeyId = None
+        self.MessageType = None
+
+
+    def _deserialize(self, params):
+        self.Algorithm = params.get("Algorithm")
+        self.Message = params.get("Message")
+        self.KeyId = params.get("KeyId")
+        self.MessageType = params.get("MessageType")
+
+
+class SignByAsymmetricKeyResponse(AbstractModel):
+    """SignByAsymmetricKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Signature: 签名，Base64编码
+        :type Signature: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Signature = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Signature = params.get("Signature")
+        self.RequestId = params.get("RequestId")
+
+
 class Tag(AbstractModel):
     """标签键和标签值
 
@@ -2267,6 +2326,60 @@ class UpdateKeyDescriptionResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class VerifyByAsymmetricKeyRequest(AbstractModel):
+    """VerifyByAsymmetricKey请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param KeyId: 密钥的唯一标识
+        :type KeyId: str
+        :param SignatureValue: 签名值，通过调用KMS签名接口生成
+        :type SignatureValue: str
+        :param Message: 消息原文或消息摘要。如果提供的是消息原文，则消息原文的长度（Base64编码前的长度）不超过4096字节。如果提供的是消息摘要，SM2签名算法的消息摘要长度（Base64编码前的长度）必须等于32字节
+        :type Message: str
+        :param Algorithm: 签名算法，支持的算法：SM2DSA
+        :type Algorithm: str
+        :param MessageType: 消息类型：RAW，DIGEST，如果不传，默认为RAW，表示消息原文。
+        :type MessageType: str
+        """
+        self.KeyId = None
+        self.SignatureValue = None
+        self.Message = None
+        self.Algorithm = None
+        self.MessageType = None
+
+
+    def _deserialize(self, params):
+        self.KeyId = params.get("KeyId")
+        self.SignatureValue = params.get("SignatureValue")
+        self.Message = params.get("Message")
+        self.Algorithm = params.get("Algorithm")
+        self.MessageType = params.get("MessageType")
+
+
+class VerifyByAsymmetricKeyResponse(AbstractModel):
+    """VerifyByAsymmetricKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SignatureValid: 签名是否有效
+        :type SignatureValid: bool
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SignatureValid = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.SignatureValid = params.get("SignatureValid")
+        self.RequestId = params.get("RequestId")
+
+
 class WhiteboxKeyInfo(AbstractModel):
     """白盒密钥信息
 
